@@ -19,6 +19,7 @@ from .persistence import (
     get_prev_next_chapters,
     get_username,
     import_follows,
+    is_manga_page_url,
     load_chapter,
     load_title,
     read,
@@ -73,15 +74,14 @@ def _decode_proxy_url(b64_url):
 
 def _is_manga_img_url(
     url,
-    pattern=re.compile(
-        r"^https://("
-        r"([\w-]+\.)?(mangadex\.org/(data|images)|(mangabeast\d{0,4}.com|hot\.granpulse\.us|fan-official\.eorzea\.us|fan-complete\.ivalice\.us)/manga)/"
-        r"|"
-        r"([\w-]+\.)+mangadex\.network:\d{2,6}/[\w-]+/data/"
-        r")"
-    ),
+    cover_pattern=re.compile(r"^https://([\w-]+\.)?mangadex\.org/(images|covers)"),
 ):
-    return pattern.match(url)
+    """
+    Check if either a cover or page img url.
+    """
+    # Mangasee has god knows how many domains for manga page images, so we can't just
+    # do a regex check, but need to query our db instead.
+    return cover_pattern.match(url) or is_manga_page_url(url)
 
 
 def proxied(url) -> str:
@@ -294,6 +294,7 @@ def api_chapter(site, title_id, chapter_id):
     chapter["prev_chapter"] = prev_chapter
     chapter["next_chapter"] = next_chapter
     chapter["site"] = site
+    chapter["is_webtoon"] = title["is_webtoon"]
     return chapter
 
 
@@ -361,7 +362,7 @@ def api_logout():
     if num_deleted != 1:
         return jsonify({"message": "Invalid token."}), 401
     resp = make_response("{}", 200)
-    resp.set_cookie("token", "", expires=0)
+    resp.set_cookie("token", "", expires=0, samesite="Strict")
     return resp
 
 
@@ -370,7 +371,7 @@ def api_logout():
 def api_follows():
     titles = get_followed_titles(request.user_id)
     for title in titles:
-        thumbnail = title_thumbnail(title["site"], title["id"])
+        thumbnail = title_thumbnail(title["site"], title["id"], title["cover_ext"])
         if title["site"] == "mangadex":
             thumbnail = proxied(thumbnail)
         title["thumbnail"] = thumbnail
@@ -381,10 +382,12 @@ def api_follows():
 def api_search(query):
     results = search_title_all_sites(query)
 
-    if "mangadex" in results:
-        for title in results["mangadex"]:
-            title["thumbnail"] = proxied(title["thumbnail"])
-    return results
+    for result in results:
+        if result["site"] == "mangadex":
+            for title in result["titles"]:
+                title["thumbnail"] = proxied(title["thumbnail"])
+            break
+    return {"results": results}
 
 
 @app.route("/api/follow", methods=["POST"])
